;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xb217ed0627b3e4bfc8e45b1a1387de55 . "./code.cg2js/cg-status-bar.fasl")
(#x92b8b41d037a498ed72a79731cd098be . "./code.cg2js/cg-hotspot.fasl")
(#x908ecc2d7929bf0a38da1e72c5c2b74b . "./code.cg2js/cg-toolbar.fasl")
(#xce3ac0b02b212a5ab7fc6332f384625a . "./code.cg2js/cg-clipboard-stack.fasl")
(#xf73df32ec0d6f2567cadfc7334b77d5c . "./code.cg2js/cg-tooltip.fasl")
(#xba89d8576259bed296660c955272abd5 . "./code.cg2js/cg-calendar.fasl")
(#x88a532a8b376e92db235375c13e9347c . "./code.cg2js/cg-item-list.fasl")
(#x907162ae9fff6b084cbdd7a532488eeb . "./code.cg2js/cg-bitmap-stream.fasl")
(#xb423b54fd19be7f445c661f2781f38d9 . "./code.cg2js/cg-trackbar.fasl")
(#x3bec01368b050c971e7e385911a06651 . "./code.cg2js/cg-class-grid.fasl")
(#x15f124b89f3fcb240c9c6c2e33d78251 . "./code.cg2js/cg-dialog-item.fasl")
(#x14d44ea59d5786f38be05994d9cc4c7c . "./code.cg2js/cg-comtab.fasl")
(#x6182fc3aa09f02da16c9a0659dcc5a36 . "./code.cg2js/cg-lisp-text.fasl")
(#x4d739c99eb29ffcc6f74f248966ab916 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x78a670116addcd26fe7fdd8270020916 . "./code.cg2js/cg-button.fasl")
(#xdf4957226e4613421aba2b94e43ca55b . "./code.cg2js/cg-printing.fasl")
(#x16f5bf47db6c3ad68a38b64ccc29b444 . "./code.cg2js/cg-pixmap-printing.fasl")
(#xe448a074c91b30711da0c4e79f8d460c . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#xd7def74a029b1e8cc5c6b779372a3e8f . "./code.cg2js/cg-pixmap-widget.fasl")
(#x146cf31dcc87f9d63d55296e8bd9a295 . "./code.cg2js/cg-selected-object.fasl")
(#xbc7571ac6d7e4721d212bb1cac4e0a69 . "./code.cg2js/cg-text-or-combo.fasl")
(#x7f019c04e629fbbb593df66c5767bd4e . "./code.cg2js/cg-graphics-context.fasl")
(#x2266cafe8ae8d33bb4aaaeb6b4f4d5c1 . "./code.cg2js/cg-edit-in-place.fasl")
(#x99c5214eddd41510a8ac8740042ffbba . "./code.cg2js/cg-string-dialog.fasl")
(#x09c0a5865c13b274ee524b052e1b81a4 . "./code.cg2js/cg-list-view.fasl")
(#x7fddaa6e44e1b588343257288ff3ff60 . "./code.cg2js/cg-intersect.fasl")
(#xe4df8b54067243989bbdbe96096f2ce2 . "./code.cg2js/cg-text-widget.fasl")
(#x14d9d2d1e42f5657ead4275842b1feca . "./code.cg2js/cg-directory-dialog.fasl")
(#x55a3383192d43e75b64dc663834f9aea . "./code.cg2js/cg-file-dialog.fasl")
(#x5d6d35effa6e885562475b43d9ed60fc . "./code.cg2js/cg-dde-utils.fasl")
(#xf0d32884ca74935b6ec3f1e2542a32d4 . "./code.cg2js/cg-nodes.fasl")
(#xea6ccecf82cd2942d15516ed8414f1c8 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x50d08690840d095c68e3a42b97bb200f . "./code.cg2js/cg-up-down-control.fasl")
(#x94cd1d80ffe9c2d4a33e2169f8ab4481 . "./code.cg2js/cg-get-position.fasl")
(#xbd1150f0545e12498f7ddd50ec8cd1ce . "./code.cg2js/cg-toggling-widget.fasl")
(#xebc9767bf4c5855cee36a683b44b1670 . "./code.cg2js/cg-acache.fasl")
(#xbbd63f83a219d05b3622a400d8df10f2 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x45d181f2a6123376137ec0262cd2b4fe . "./code.cg2js/cg-base.fasl")
(#xf438650ce64091a8d543b500691639eb . "./code.cg2js/cg-drag-and-drop.fasl")
(#x9fd591bdb2bae091ffa900e84437eab8 . "./code.cg2js/cg-find-string-dialog.fasl")
(#xca27cc3eddc6431f288969840d92f223 . "./code.cg2js/cg-property.fasl")
(#x82e5b147d65766ee2fd0d994a96bfccb . "./code.cg2js/cg-editable-text.fasl")
(#xcc34e8d3bf1036ee4d1bd96c37f1a20a . "./code.cg2js/cg-lamp.fasl")
(#xf65390d9a4ee8ddfc9872521f05d4f04 . "./code.cg2js/cg-progress-indicator.fasl")
(#x46895b83db5bd9e7405be9ac2f1e7127 . "./code.cg2js/cg-chart-widget.fasl")
(#x66c77ea1aa3da3e43d88add5246e8615 . "./code.cg2js/cg-common-control.fasl")
(#x31770d9255eb1d15a567d1fcd4766839 . "./code.cg2js/cg-font-dialog.fasl")
(#x2ed82ffb41165eacc3b5176c85a58d1c . "./code.cg2js/cg-gesture-emulation.fasl")
(#x5ce7fbc7c19a7598eaffe27a0eca57e7 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x01b896f46ad2c9031504018ceda80294 . "./code.cg2js/cg-os-window.fasl")
(#x26e7671548cefd7d178c01bbc4e8fc56 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x34d392ca33619325baea1fae336fa215 . "./code.cg2js/cg-pixmap.fasl")
(#xe1f22a4653120bee2cd880ce5b592383 . "./code.cg2js/cg-chart-or-plot.fasl")
(#x5e48c6263da10bee17508b7025e80868 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#xe9a684714a9b5de7b98249731c339cf0 . "./code.cg2js/cg-scaling-stream.fasl")
(#xc3238087f9cb58caf066604cda80951b . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xf5f8b15ec476a2ec77be331ca21c157d . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x20631f2b4009b689f58f80c3ff17ff35 . "./code.cg2js/cg-timer.fasl")
(#x9291c62061229aadb7e2c1e0ed0edfa5 . "./code.cg2js/cg-scroll-bar.fasl")
(#x458db08bf840db01b60a79a8049567e7 . "./code.cg2js/cg-caret.fasl")
(#x7df30655dcf05cffe0459777ba7e404a . "./code.cg2js/cg-template-string.fasl")
(#x90e67db1cf2259d25543dc282a0b50e6 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x5407c4a8e33b2d01da36ca7d183ee56f . "./code.cg2js/cg-directory-dialog-os.fasl")
(#xf9a3691b0cd99c3540757e1728e1e0b2 . "./code.cg2js/cg-rich-edit.fasl")
(#x23cb6d33fa7d9ff198308628f6a979ce . "./code.cg2js/cg-combo-box.fasl")
(#xbcd067f89f481a99754703345fcb5c70 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x3fde93ce4ea38590313ce4743e357653 . "./code.cg2js/cg-multi-picture-button.fasl")
(#x6ee1cbc0e83c9ddd2f17f3cd18f71a6b . "./code.cg2js/cg-menu-tooltip.fasl")
(#x24595632baae5a04f3ef94249f4d6c1e . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x37f24ad8cc16c43b43658c019f9e6b9c . "./code.cg2js/cg-outline.fasl")
(#xa4b7b799ecc9aa481b18f9ce2f60e412 . "./code.cg2js/cg-class-support.fasl")
(#x39c5110eca405e0c23edfe64d9e6724f . "./code.cg2js/cg-header-control.fasl")
(#x3eeea723ec7965190bff72da7954364c . "./code.cg2js/cg-lettered-menu.fasl")
(#xf633c4c2ca0a75e1b9addcc9b36841f3 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xa56be1028b1ab0600534194905bc7a74 . "./code.cg2js/cg-fill-texture.fasl")
(#xa55d780ed8ae0b72534ebd0d04276434 . "./code.cg2js/cg-lisp-widget.fasl")
(#x584fae294e2d6650106cf05b586352a1 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x1e04b839590f85db92a1518a5509eca8 . "./code.cg2js/cg-clipboard.fasl")
(#x5291e1f98b2fdcdfdf03927e1ad3600b . "./code.cg2js/cg-wrap-string.fasl")
(#xf8fa626c2eb5ae3dc417bdfdc514aede . "./code.cg2js/cg-os-widget.fasl")
(#x92894203902a6a3c577eb6c94b151767 . "./code.cg2js/cg-check-box.fasl")
(#xc12bd6f4304166c6f9017c2f5a79bbab . "./code.cg2js/cg-choice-list.fasl")
(#x42d7df2649853593395cb7d42cab8ecb . "./code.cg2js/cg-layout.fasl")
(#xac12cef9f0893193581547fae36aa225 . "./code.cg2js/cg-group-box.fasl")
(#x19b2b1178353d460234b590af3b709a1 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xe17a7f0a7dafb041ffee882fd5001fd4 . "./code.cg2js/cg-radio-button.fasl")
(#xe2ff40fb7b942cb291e788b75eeb0389 . "./code.cg2js/cg-tab-control.fasl")
(#xa177f9f1ad08e0ca0c473ffcd1e63527 . "./code.cg2js/cg.fasl")
(#x31b6305b49b6125608b9b916a16a3139 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#xa64e345d00ef480e43d776dbea5b0221 . "./code.cg2js/cg-dropping-outline.fasl")
(#x1db3125f6fd22aff7f9739bebf386c33 . "./code.cg2js/cg-get-pixmap.fasl")
(#x0c1af32569691b9eca65a592b893bc4e . "./code.cg2js/cg-grid-widget.fasl")
(#xab5abd1bfbac428f1ebe24bcad6d0d5c . "./code.cg2js/cg-utility-dialog.fasl")
(#xcb0980d35b37c6f5e9c2b2ca0af1267d . "./code.cg2js/cg-static-text.fasl")
(#xe39c67fd0a6a5ce80dd74607498e50d3 . "./code.cg2js/cg-class-slot-grid.fasl")
(#x902c9033387c76499ef801d3e6f0b2a0 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x60f3c75f0cb4b03e4b0114510c4f67ea . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#xee500bbea2f75e803f45826399ece4aa . "./code.cg2js/cg-bitmap-pane.fasl")
(#x04b8cedb943cd8591101bc4516b4552b . "./code.cg2js/cg-plot-widget.fasl")
(#x329524ac1a6061ac58efe1c230e3d860 . "./code.cg2js/cg-color-dialog.fasl")
(#xfdbb5a7a4e1fb0288e2ec7dfd0697679 . "./code.cg2js/cg-icon-pixmap.fasl")
(#x956f7d64706249d70998d9cc51a804ae . "./code.cg2js/cg-icon.fasl")
(#x43f96bb8d2a4cb054426574d0313afd8 . "./code.cg2js/cg-dev.fasl")
(#x096f15e8cc24c2a7c809946e9fbe8fcd . "./code.cg2js/cg-choose-printer.fasl")
(#xafe9b5e2c71b00ee7f27823fb462f1f8 . "./code.cg2js/cg-intersect-posbox.fasl")
(#x67d40adb1674d1cb7cde99ab5cc9b8da . "./code.cg2js/cg-menu.fasl")
(#x88a7b6cd91de2eed2780203c476826c7 . "./code.cg2js/cg-yes-no-list.fasl")
(#x27f3ae8443e14fce91333f3f4d6dad85 . "./code.cg2js/cg-palette.fasl")
(#x87410249298d608cedaf761ef19f6dc3 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x3f035e51fcc35aeef840c970d69c0033 . "./code.cg2js/cg-message-dialog.fasl")
(#x021638a369676146fce098a085aa6570 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x34427e9c60f20e6c9f60f35e6f821f13 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#xcb24c3ae9d7796fbcedae78169579886 . "./code.cg2js/cg-split-bar.fasl")
(#x5eb208edfa6294257a05a9af03fad633 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x2757354579d0495ac59753852106a441 . "./code.cg2js/cg-web-browser.fasl")
(#xa3530959757e97a07e0e2082b595e153 . "./code.cg2js/cg-project-window.fasl")
(#x241fffd980301cf70c1a5d39ec92fed8 . "./code.cg2js/cg-picture-widget.fasl")
(#x0b3085e53faeec4a0164774319e4aac9 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x4cca33a837080d70fc2fdda872c6e365 . "./code.cg2js/cg-object-editor.fasl")
(#x7c991735a826cf225d41130fe9723e4f . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x5e1e1403ce62e4519f474328c3ee0c7d . "./code.cg2js/cg-paren-matching.fasl")
(#x576cbcb65c64d972d68807b50d789ffc . "./code.cg2js/cg-sample-file-menu.fasl")
(#xe63eeaf9928939f2aa03ac155b79f0a1 . "./code.cg2js/cg-drawable.fasl")
(#x08a979ceb5adb96ab7638d9efa61171e . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x452dfbecb4137dff3994b085ee221540 . "./code.cg2js/cg-html-widget.fasl")
(#x5175b216019961dcd7f45b6c5acd4816 . "./code.cg2js/cg-curve.fasl")
(#xb41723695372c9a036abec63ccc6115a . "./code.cg2js/cg-yes-no-string.fasl")
(#x8f0348fe19ff266277092a6edff837ac . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x1a28d87a8931566b137f1b067df91330 . "./code.cg2js/cg-html-dialog.fasl")
(#x28aa02e5344d84010780acd69a797be9 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x257515cf931cd207dd124394b2811a37 . "./code.cg2js/cg-tray.fasl")
(#xf5adb5fcb243910b0f15ce663752fb75 . "./code.idejs/ide-apropos.fasl")
(#x8986476b29e9abc60964f4b8827d7fff . "./code.idejs/ide-window-list.fasl")
(#x648ac145d5ddcce71ec74ee4b13955bc . "./code.idejs/ide-class-browser.fasl")
(#xd473d079486f8985762030b823a69a59 . "./code.idejs/ide-base.fasl")
(#x6c638fa6bc98c024cfd8a9468b95a2a8 . "./code.idejs/ide-process-browser.fasl")
(#x7fcaa48dd83cfa11c12d5b02053e1ddd . "./code.idejs/ide-acache.fasl")
(#xd149c112fe7134bc922294cbf4775c34 . "./code.idejs/ide-navigator.fasl")
(#xb0685c1bc3ca44e388737188a1817637 . "./code.idejs/ide-trace.fasl")
(#xfa1bcc35aa0f7965eba4518538b9c5fd . "./code.idejs/ide-project.fasl")
(#xe307cec6e1e5d6c64de502518f8466c6 . "./code.idejs/ide-patch-dialog.fasl")
(#x4381a2fa6f0f6b3151929b07265c38b6 . "./code.idejs/ide-grapher.fasl")
(#x7a3def2a51bf39077e21d52d10e03c15 . "./code.idejs/ide-dev.fasl")
(#x3eed371ad9d300891fc50929d6365461 . "./code.idejs/ide-keyshort.fasl")
(#xaa24d23fcf651433c0077b4e60270e43 . "./code.idejs/ide-editor.fasl")
(#x1e47921cbcf30c8caaf264a1fd09e760 . "./code.idejs/ide-inspector.fasl")
(#xf145c70fbfb24e2ff99b83f6ef8a9c28 . "./code.idejs/ide.fasl")
(#xc318534ecb09eb0e081a8710832c3e47 . "./code.idejs/ide-clipboard.fasl")
(#xf9af90f4731c288ea04c5425236e28a8 . "./code.idejs/ide-find-definitions.fasl")
(#x1b312a5ac76b389a8f9a8220ffcc9402 . "./code.idejs/ide-form.fasl")
(#xfdc6123d16e0b492029fefc570726dc4 . "./code.idejs/ide-intro.fasl")
(#x1592b1783959e53f82afce50f9a9c93b . "./code.idejs/ide-find-in-files.fasl")
(#xb391a6bae83d34f67166a9e80fa30537 . "./code.idejs/ide-package-list.fasl")
(#x46107e93788fb4a4cefdf54d81de53d9 . "./code.idejs/ide-class-grapher.fasl")
(#x785b009207cd19fe54c93fc535e484ec . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
